#ifndef NT2_INCLUDE_CONSTANTS__180_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS__180_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/_180.hpp>

#endif
